<?php
/***************************************************************************
 *  Copyright (C) 
 *  This file is part of WOOPRESS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/

// Sécurité
if ( !defined ( 'WOOPRESS' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}


class Template
{
    private $texte = '';
    private $vars = array ();
    private $blocks = array ();


    // Constructeur : adresse du fichier
    public function __construct ( $fichier )
    {
        if ( !is_file ( $fichier ) )
        {
            return false;
        }
    
        $file = fopen ( $fichier , 'r' );

        if ( !$file )
        {
            return false;
        }

        while ( !feof ( $file ) )
        {
            // On récupère une ligne
            $this->texte .= fgets ( $file , 255 );
        }

        fclose ( $file );

        return true;
    }


    // Définition des variables à transformer dans la page
    public function SetVar ( array $vars )
    {
        if ( !is_array ( $vars ) )
        {
            return false;
        }

        foreach ( $vars as $var => $val )
        {
            if ( preg_match ( "#^[A-Z\#_]{1,}$#" , $var ) )
            {
                $this->vars[$var] = $val;
            }
        }

        return true;
    }


    // Retourne le texte de la page
    public function Parse ()
    {
        // Transformation des blocs
        foreach ( $this->blocks as $block_name => $block_content )
        {
            // Contenu du bloc
            $block_ctn = preg_replace ( "#^(.{0,})<!--" . $block_name . ":START-->(.+)<!--" . $block_name . ":END-->(.{0,})$#sU" , "$2" , $this->texte );
            $block_txt = '';

            // Pour chaque ligne du bloc
            foreach ( $block_content as $block_row )
            {
                $block_txt .= $block_ctn;

                // Pour chaque variable de la ligne
                foreach ( $block_row as $var => $val )
                {
                    $block_txt = str_replace ( '{' . $block_name . ':' . $var . '}' , $val , $block_txt );
                }
            }

            $this->texte = preg_replace ( "#^(.{0,})<!--" . $block_name . ":START-->(.+)<!--" . $block_name . ":END-->(.{0,})$#sU" , "$1" . $block_txt . "$3" , $this->texte );
        }

        // Transformation des variables
        foreach ( $this->vars as $var => $val )
        {
            $this->texte = str_replace ( '{' . $var . '}' , $val , $this->texte );
        }

        return $this->texte;
    }


    // Définition d'un bloc
    public function SetBlock ( $name , array $vars )
    {
        if ( !is_array ( $vars ) || !preg_match ( "#^[A-Z\#_]{1,}$#" , $name ) )
        {
            return false;
        }

        if ( !isset ( $this->blocks[$name] ) )
        {
            $this->blocks[$name] = array ();
        }

        $this->blocks[$name][] = $vars;

        return true;
    }
}

?>