<?php
/***************************************************************************
 *  Copyright (C) 
 *  This file is part of WOOPRESS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/

// Sécurité
if ( !defined ( 'WOOPRESS' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}

// Démarrage des sessions
session_start ();


// Timestamp (pour avoir une seule valeur durant le chargement de la page)
$time = time ();


// Fuseau horaire (valable pour PHP 5.1 et supérieur)
if ( version_compare ( PHP_VERSION , '5.1' , '>' ) )
{
    date_default_timezone_set ( 'Europe/Paris' );
}


// Version de PHP
$php_version = 'php' . substr ( PHP_VERSION , 0 , 1 );


////////////////////
// Fonctions
////////////////////

if ( is_file ( './systeme/lib_' . $php_version . '/fonctions.' . EXT ) )
{
    include_once ( './systeme/lib_' . $php_version . '/fonctions.' . EXT );
}
else
{
    die ( '<p><strong>Erreur&nbsp;:</strong> Le fichier systeme/lib_' . $php_version . '/fonctions.' . EXT . ' est introuvable.</p>' );
}

$site = new Site ();


// Template
if ( FichierExiste ( './systeme/lib_' . $php_version . '/templates.' . EXT , true ) )
{
    include_once ( './systeme/lib_' . $php_version . '/templates.' . EXT );
}


// GeSHi
if ( FichierExiste ( './systeme/lib_' . $php_version . '/geshi.' . EXT , true ) )
{
    include_once ( './systeme/lib_' . $php_version . '/geshi.' . EXT );
}


////////////////////
// Installation du logiciel
////////////////////

if ( !is_file ( './systeme/configuration.' . EXT ) && $page != 'Installation' )
{
    header ( 'Location: index.' . EXT . '?page=Installation&etape=1' );
    die ( -1 );
}


////////////////////
// Base de données
////////////////////

if ( FichierExiste ( './systeme/lib_' . $php_version . '/db_' . SGBD . '.' . EXT , true ) )
{
    include_once ( './systeme/lib_' . $php_version . '/db_' . SGBD . '.' . EXT );
}

switch ( SGBD )
{
    default:
    case 'mysql': $database = new MySQL ();      break;
}

////////////////////
// Configuration du site
////////////////////

$configuration = array ();

$config_defaut = array (
    'accueil_mod'       => 'news',
    'accueil_texte'     => 'Bienvenue sur mon site !',
    'adresse'           => '',
    'bloquage'          => 0,
    'bloquage_texte'    => "Le site est temporairement fermé et devrait être accessible prochainement. Veuillez revenir plus tard.\n\nLes raisons possibles sont une maintenance du serveur, une mise-à-jour du site ou de la base de données, ou encore une fermeture pour cause de vandalisme ou de piratage.",
    'captcha'           => 1,
    'copyright'         => '',
    'decalage'          => 0,
    'description'       => '',
    'email'             => '',
    'equipe'            => '3',
    'file_mode'         => 'private',
    'format_date'       => 'd/m/Y',
    'format_heure'      => 'H:i:s',
    'inscription'       => 'mail',
    'keywords'          => '',
    'langue'            => 'fr',
    'liens'             => '',
    'menus'             => 'Recherche;Communaute;LastMessages',
    'navigation'        => 'Accueil;News;Articles;Forums;Sondages;Administration',
    'numero_autour'     => 2,
    'numero_debut'      => 3,
    'numero_fin'        => 3,
    'page_commentaires' => 20,
    'page_livre_or'     => 10,
    'page_membres'      => 50,
    'page_messages'     => 20,
    'page_news_accueil' => 10,
    'page_news'         => 50,
    'page_pm'           => 20,
    'page_sujets'       => 50,
    'popup'             => 1,
    'record_visiteurs'  => 1,
    'record_time'       => $time,
    'stat_count'        => 'hits',
    'stat_time'         => 300,
    'style'             => 'Woopress',
    'sujets_deplaces'   => 1,
    'titre'             => 'Woopress',
    'tps_msg_up'        => 86400,
    'tps_msg'           => 300,
    'tps_sujet'         => 300,
    'upload_taille'     => 50000,
    'upload_total'      => 1000000,
    'upload_extensions' => 'png;jpg;jpeg;gif'
);

if ( $page != 'Installation' && $database->connected )
{
    $sql = "SELECT config_nom,
                   config_valeur
            FROM " . $database->pref . "configuration;";

    $req = $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );

    while ( $row = $database->ResultArray ( $req ) )
    {
        $configuration[$row['config_nom']] = $row['config_valeur'];
    }

    foreach ( $config_defaut as $config_name => $config_value )
    {
        if ( !isset ( $configuration[$config_name] ) )
        {
            $configuration[$config_name] = $config_value;

            $sql = 'INSERT INTO ' . $database->pref . "configuration
                    (config_nom, config_valeur)
                    VALUES
                    ('" . $config_name . "', '" . $database->Protege ( $config_value ) . "');";

            $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );
        }
    }
}
else
{
    $configuration = $config_defaut;
}


////////////////////
// Membre connecté ?
////////////////////

$_SESSION['groupe'] = 1;

if ( $page != 'Installation' && $database->connected && ( !isset ( $_SESSION['membre'] ) || !isset ( $_SESSION['membre_id'] ) ) && !empty ( $_COOKIE['membre_nom'] ) && !empty ( $_COOKIE['membre_id'] ) && !empty ( $_COOKIE['membre_mdp'] ) )
{
    $sql = "SELECT membre_id,
                   membre_nom,
                   membre_mdp,
                   membre_groupe
            FROM " . $database->pref . "membres
            WHERE
                    membre_id = '" . $database->Protege ( $_COOKIE['membre_id'] ) . "'
                AND membre_nom = '" . $database->Protege ( $_COOKIE['membre_nom'] ) . "'
                AND membre_mdp = '" . $database->Protege ( $_COOKIE['membre_mdp'] ) . "';";

    $req = $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );

    if ( $database->NbrRowsSelected ( $req ) === 0 )
    {
        unset ( $_SESSION['membre'] );
        unset ( $_SESSION['membre_id'] );
        $_SESSION['groupe'] = 1;

        setcookie ( 'membre_nom' );
        setcookie ( 'membre_id' );
        setcookie ( 'membre_mdp' );
    }
    else
    {
        $row = $database->ResultArray ( $req );

        $_SESSION['membre'] = $row['membre_nom'];
        $_SESSION['membre_id'] = $row['membre_id'];
        $_SESSION['groupe'] = $row['membre_groupe'];

        $nbr_new_private_msg = 0;

        setcookie ( 'membre_nom' , $row['membre_nom'] , $time + 31536000 );
        setcookie ( 'membre_id' , $row['membre_id'] , $time + 31536000 );
        setcookie ( 'membre_mdp' , $row['membre_mdp'] , $time + 31536000 );
    }
}


////////////////////
// Informations sur le visiteur
////////////////////

if ( $page != 'Installation' && $database->connected && isset ( $_SESSION['membre'] ) && isset ( $_SESSION['membre_id'] ) )
{
    $sql = "SELECT membre_langue,
                   membre_style,
                   membre_groupe,
                   membre_popup,
                   membre_decalage,
                   groupe_nbrmp,
                   COUNT(msg_box_lu) AS nbr_pm
            FROM " . $database->pref . "membres
            LEFT JOIN " . $database->pref . "groupes
                ON groupe_id = membre_groupe
            LEFT JOIN " . $database->pref . "msg_box
                ON msg_box_membre = '" . $_SESSION['membre_id'] . "'
                    AND msg_box_lu = '0'
            WHERE
                    membre_id = '" . $_SESSION['membre_id'] . "'
                AND membre_nom = '" . $_SESSION['membre'] . "'
            GROUP BY membre_id;";

    $req = $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );

    if ( $database->NbrRowsSelected ( $req ) > 0 )
    {
        $row = $database->ResultArray ( $req );

        $configuration['nbr_msg'] = $row['groupe_nbrmp'];
        $configuration['popup'] = $row['membre_popup'];
        $configuration['decalage'] = $row['membre_decalage'];

        // On récupère les informations de configuration du membre
        if ( is_file ( './langues/langue_' . $row['membre_langue'] . '.' . EXT ) )
        {
            $configuration['langue'] = $row['membre_langue'];
        }

        if ( is_dir ( './themes/' . $row['membre_style'] ) )
        {
            $configuration['style'] = $row['membre_style'];
        }

        $_SESSION['groupe'] = $row['membre_groupe'];

        // Nombre de messages privés non lus
        $nbr_new_private_msg = $row['nbr_pm'];

        // Mise-à-jour de la date de la dernière visite
        $sql = "UPDATE " . $database->pref . "membres
                SET membre_visite = '" . $time . "'
                WHERE
                    membre_id = '" . $_SESSION['membre_id'] . "'
                AND membre_nom = '" . $_SESSION['membre'] . "';";

        $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );
    }
    else
    {
        unset ( $_SESSION['membre'] );
        unset ( $_SESSION['membre_id'] );
        $_SESSION['groupe'] = 1;

        setcookie ( 'membre_nom' );
        setcookie ( 'membre_id' );
        setcookie ( 'membre_mdp' );
    }
}


////////////////////
// Droits
////////////////////

$droit = array ();

// Valeurs par défaut
$droit_defaut = array (
    'accueil_edition'           => 0,
    'administration'            => 0,
    'article_commentaire'       => 0,
    'article_edition'           => 0,
    'article_edition_auteur'    => 0,
    'article_lecture'           => 1,
    'article_sup'               => 0,
    'article_sup_auteur'        => 0,
    'commentaire_edit'          => 0,
    'commentaire_edit_auteur'   => 1,
    'commentaire_sup'           => 0,
    'commentaire_sup_auteur'    => 0,
    'deplacer_sujet'            => 0,
    'fiche_lecture'             => 1,
    'message_edition_auteur'    => 0,
    'message_edition'           => 0,
    'message_lecture'           => 1,
    'message_sup_auteur'        => 0,
    'message_sup'               => 0,
    'news_commentaire'          => 0,
    'news_edition_auteur'       => 0,
    'news_edition'              => 0,
    'news_lecture'              => 1,
    'reponse_automatique'       => 0,
    'sondage_lecture'           => 1,
    'sondage_repondre'          => 0,
    'sujet_edition_auteur'      => 0,
    'sujet_edition'             => 0,
    'sujet_epingle'             => 0,
    'sujet_fermer'              => 0,
    'sujet_lecture'             => 1,
    'upload'                    => 0
);


if ( $page != 'Installation' && $database->connected )
{
    $sql = "SELECT droit_valeur,
                   droit_nom
            FROM " . $database->pref . "droits
            WHERE droit_groupe = '" . $_SESSION['groupe'] . "';";

    $req = $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );

    while ( $row = $database->ResultArray ( $req ) )
    {
        $droit[$row['droit_nom']] = $row['droit_valeur'];
    }

    foreach ( $droit_defaut as $droit_name => $droit_value )
    {
        if ( !isset ( $droit[$droit_name] ) )
        {
            $configuration[$droit_name] = $droit_value;

            $sql = "INSERT INTO " . $database->pref . "droits
                    (droit_groupe, droit_nom, droit_valeur)
                    VALUES
                    ('" . $_SESSION['groupe'] . "', '" . $droit_name . "', '" . $droit_value . "');";

            $database->Requete ( $sql ) or $database->Erreur ( __LINE__ , __FILE__ , $sql );
        }
    }
}


////////////////////
// Langues
////////////////////

if ( FichierExiste ( './langues/langue.' . EXT ) )
{
    include_once ( './langues/langue.' . EXT );
}

// Inclusion du fichier de langue
if ( FichierExiste ( './langues/langue_' . $configuration['langue'] . '.' . EXT ) )
{
    include_once ( './langues/langue_' . $configuration['langue'] . '.' . EXT );
}


// Liste des langues
$langues = array ();

if ( $dh = opendir ( './langues' ) )
{
    while ( ( $file = readdir ( $dh ) ) !== false )
    {
        if ( !is_dir ( './langues/' . $file ) && preg_match ( "#^langue_(.+)." . EXT . "$#" , $file ) )
        {
            $file = preg_replace ( "#^langue_(.+)." . EXT . "$#" , "$1" , $file );

            $langues[$langue['langue_' . $file]] = $file;
        }
    }

    closedir ( $dh );
}


////////////////////
// Liste des thèmes
////////////////////

$themes = array ();

if ( $dh = opendir ( './themes' ) )
{
    while ( ( $file = readdir ( $dh ) ) !== false )
    {
        if ( is_dir ( './themes/' . $file ) && $file != '.' && $file != '..' && $file != 'commun' )
        {
            $themes[$file] = $file;
        }
    }

    closedir ( $dh );
}


////////////////////
// Variables
////////////////////

// Expression recherchée
$exp = ( isset ( $_POST['expression'] ) ) ? $_POST['expression'] : '';


// Variables de la page
$page_titre = '';
$page_texte = '';
$page_infos = 'Inconnue';
$page_include = 1;
$page_simple = 0;
$page_CSS = '';

?>